@@ -15,20 +15,20 @@ function(Envelope) {
   
   NumberOfSimulations <- dim(SimulatedValues)[2]
   AverageSimulatedValues <- apply(SimulatedValues, 1, sum)/(NumberOfSimulations-1)
-  rIncrements <- (r-c(0,r)[1:length(r)])[2:length(r)]
+  rIncrements <- (r-c(0,r)[seq_along(r)])[-1]
   
   # Ui calculate the statistic for a simulation 
   Ui <- function(SimulationNumber) {
-    Departure <- (SimulatedValues[, SimulationNumber]-AverageSimulatedValues)[1:length(r)-1]
+    Departure <- (SimulatedValues[, SimulationNumber]-AverageSimulatedValues)[seq_along(r)-1]
     WeightedDeparture <- (Departure[!is.nan(Departure)])^2*rIncrements[!is.nan(Departure)]
     return(sum(WeightedDeparture))
   }
   
   # Calculate the Ui statistic for all simulations
-  SimulatedU <- sapply(1:NumberOfSimulations, Ui)
+  SimulatedU <- vapply(seq_len(NumberOfSimulations), Ui, FUN.VALUE=0.0)
 
   # Calculate the statistic for the actual value
-  RecenteredValues <- (ActualValues-AverageSimulatedValues)[1:length(r)-1]
+  RecenteredValues <- (ActualValues-AverageSimulatedValues)[seq_along(r)-1]
   WeightedRecenteredValues <- (RecenteredValues[!is.nan(RecenteredValues)])^2*rIncrements[!is.nan(RecenteredValues)]
   ActualU <- sum(WeightedRecenteredValues)
   
